@@ -70,6 +70,7 @@ func (b *Block) InitPlain(env platform.Environment, config *Config) {
 		AnsiColors:         config.MakeColors(),
 		TrueColor:          env.Flags().TrueColor,
 	}
+
 	b.writer.Init(shell.GENERIC)
 	b.env = env
 	b.executeSegmentLogic()
@@ -79,12 +80,14 @@ func (b *Block) executeSegmentLogic() {
 	if shouldHideForWidth(b.env, b.MinWidth, b.MaxWidth) {
 		return
 	}
+
 	b.setEnabledSegments()
 	b.setSegmentsText()
 }
 
 func (b *Block) setActiveSegment(segment *Segment) {
 	b.activeSegment = segment
+	b.writer.Interactive = segment.Interactive
 	b.writer.SetColors(segment.background(), segment.foreground())
 }
 
@@ -176,38 +179,70 @@ func (b *Block) writeSeparator(final bool) {
 	if isPreviousDiamond {
 		b.adjustTrailingDiamondColorOverrides()
 	}
+
 	if isPreviousDiamond && isCurrentDiamond && len(b.activeSegment.LeadingDiamond) == 0 {
 		b.writer.Write(ansi.Background, ansi.ParentBackground, b.previousActiveSegment.TrailingDiamond)
 		return
 	}
+
 	if isPreviousDiamond && len(b.previousActiveSegment.TrailingDiamond) > 0 {
 		b.writer.Write(ansi.Transparent, ansi.ParentBackground, b.previousActiveSegment.TrailingDiamond)
 	}
 
-	resolvePowerlineSymbol := func() string {
-		var symbol string
-		if b.activeSegment.isPowerline() {
-			symbol = b.activeSegment.PowerlineSymbol
-		} else if b.previousActiveSegment != nil && b.previousActiveSegment.isPowerline() {
-			symbol = b.previousActiveSegment.PowerlineSymbol
+	isPowerline := b.activeSegment.isPowerline()
+
+	shouldOverridePowerlineLeadingSymbol := func() bool {
+		if !isPowerline {
+			return false
 		}
-		return symbol
+
+		if isPowerline && len(b.activeSegment.LeadingPowerlineSymbol) == 0 {
+			return false
+		}
+
+		if b.previousActiveSegment != nil && b.previousActiveSegment.isPowerline() {
+			return false
+		}
+
+		return true
 	}
+
+	if shouldOverridePowerlineLeadingSymbol() {
+		b.writer.Write(ansi.Transparent, ansi.Background, b.activeSegment.LeadingPowerlineSymbol)
+		return
+	}
+
+	resolvePowerlineSymbol := func() string {
+		if isPowerline {
+			return b.activeSegment.PowerlineSymbol
+		}
+
+		if b.previousActiveSegment != nil && b.previousActiveSegment.isPowerline() {
+			return b.previousActiveSegment.PowerlineSymbol
+		}
+
+		return ""
+	}
+
 	symbol := resolvePowerlineSymbol()
 	if len(symbol) == 0 {
 		return
 	}
+
 	bgColor := ansi.Background
-	if final || !b.activeSegment.isPowerline() {
+	if final || !isPowerline {
 		bgColor = ansi.Transparent
 	}
+
 	if b.activeSegment.style() == Diamond && len(b.activeSegment.LeadingDiamond) == 0 {
 		bgColor = ansi.Background
 	}
+
 	if b.activeSegment.InvertPowerline {
 		b.writer.Write(b.getPowerlineColor(), bgColor, symbol)
 		return
 	}
+
 	b.writer.Write(bgColor, b.getPowerlineColor(), symbol)
 }
 
